package com.sun.media.sound;

import javax.sound.midi.MidiDevice;

public final class MidiInDeviceProvider extends AbstractMidiDeviceProvider
{
    private static AbstractMidiDeviceProvider.Info[] infos;
    private static MidiDevice[] devices;
    private static final boolean enabled;
    
    public MidiInDeviceProvider() {
    }
    
    @Override
    AbstractMidiDeviceProvider.Info createInfo(int n) {
        if (!MidiInDeviceProvider.enabled) {
            return null;
        }
        return new MidiInDeviceProvider.MidiInDeviceInfo(n, MidiInDeviceProvider.class);
    }
    
    @Override
    MidiDevice createDevice(AbstractMidiDeviceProvider.Info info) {
        if (MidiInDeviceProvider.enabled && info instanceof MidiInDeviceProvider.MidiInDeviceInfo) {
            return new MidiInDevice(info);
        }
        return null;
    }
    
    @Override
    int getNumDevices() {
        if (!MidiInDeviceProvider.enabled) {
            return 0;
        }
        return nGetNumDevices();
    }
    
    @Override
    MidiDevice[] getDeviceCache() {
        return MidiInDeviceProvider.devices;
    }
    
    @Override
    void setDeviceCache(MidiDevice[] devices) {
        MidiInDeviceProvider.devices = devices;
    }
    
    @Override
    AbstractMidiDeviceProvider.Info[] getInfoCache() {
        return MidiInDeviceProvider.infos;
    }
    
    @Override
    void setInfoCache(AbstractMidiDeviceProvider.Info[] infos) {
        MidiInDeviceProvider.infos = infos;
    }
    
    private static native int nGetNumDevices();
    
    private static native String nGetName(int p0);
    
    private static native String nGetVendor(int p0);
    
    private static native String nGetDescription(int p0);
    
    private static native String nGetVersion(int p0);
    
    static String access$100(int n) {
        return nGetName(n);
    }
    
    static String access$200(int n) {
        return nGetVendor(n);
    }
    
    static String access$300(int n) {
        return nGetDescription(n);
    }
    
    static String access$400(int n) {
        return nGetVersion(n);
    }
    
    static {
        MidiInDeviceProvider.infos = null;
        MidiInDeviceProvider.devices = null;
        Platform.initialize();
        enabled = Platform.isMidiIOEnabled();
    }
    
    static final class MidiInDeviceInfo extends AbstractMidiDeviceProvider.Info
    {
        private final Class providerClass;
        
        private MidiInDeviceInfo(int n, Class providerClass) {
            super(MidiInDeviceProvider.access$100(n), MidiInDeviceProvider.access$200(n), MidiInDeviceProvider.access$300(n), MidiInDeviceProvider.access$400(n), n);
            this.providerClass = providerClass;
        }
    }
}
